#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_FAM_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_FAM_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/fam.hpp>

#endif
